==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sq.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeri",
    "There was a problem reading files from this album" : "Pati një problem me leximin e kartelave prej këtij albumi",
    "Aborting preview. Could not find the file" : "Po ndërpritet paraparja. S’u gjet dot kartela",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "Gallery view" : "Pamje Galeri",
    "Could not load the description" : "S’ngarkoi dot përshkrimin",
    "Could not load the description: " : "S’ngarkoi dot përshkrimin: ",
    "Copyright" : "Të drejta kopjimi",
    "Could not load the copyright notice: " : "S’u ngarkua dot shënimi mbi të drejta kopjimi: ",
    "Copyright notice" : "Shënim të drejtash kopjimi",
    "Link to copyright document" : "Lidhje për te dokumenti i të drejtave të kopjimit",
    "This application may not work properly on your browser." : "Ky aplikacion mund të mos punojë si duhet në shfletuesin tuaj.",
    "For an improved experience, please install one of the following alternatives" : "Për një punim më të mirë, ju lutemi, instaloni një nga alternativat vijuese",
    "Your browser is not supported!" : "Shfletuesi juaj nuk mbulohet!",
    "please install one of the following alternatives" : "ju lutemi, instaloni një alternativat vijuese",
    "Album cannot be shown" : "Albumi s’shfaqet dot",
    "No media files found" : "S’u gjetën kartela media",
    "Upload pictures in the files app to display them here" : "Ngarkoni foto te aplikacioni i kartelave që t’i shfaqni këtu",
    "Upload new files via drag and drop or by using the [+] button above" : "Ngarkoni kartela të reja përmes teknikës merr dhe vër, ose duke përdorur butonin [+] me sipër",
    "Configuration error" : "Gabim formësimi",
    "New" : "E re",
    "Hide Album" : "Fshihe Albumin",
    "Could not hide album" : "Albumi s’u fsheh dot",
    "Error loading slideshow template" : "Gabim gjatë ngarkimit të gjedhes për diapozitiva",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Gabim!</strong> S’u prodhua dot një paraparje e kësaj kartele.<br>Ju lutemi, kaloni te diapozitiva pasuese, teksa heqim këtë figurë nga paraqitja",
    "Next" : "Pasuesja",
    "Play" : "Luaje",
    "Pause" : "Pauzë",
    "Previous" : "E mëparshmja",
    "Close" : "Mbylle",
    "Download" : "Shkarko",
    "Toggle background" : "Ndërroni sfondin",
    "Delete" : "Fshije",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "Upload" : "Ngarkoje",
    "Error" : "Gabim",
    "Error while sharing" : "Gabim gjatë ndarjes me të tjerët",
    "Error while unsharing" : "Gabim gjatë heqjes së ndarjes me të tjerët",
    "Error while changing permissions" : "Gabim gjatë ndryshimit të lejeve",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "Share with users or groups …" : "Ndajeni me përdorues ose grupe …",
    "Share with users, groups or remote users …" : "Ndajeni me përdorues, grupe ose përdorues të largët …",
    "Share" : "Ndajeni me të tjerët",
    "Share link" : "Ndani lidhjen",
    "The public link will expire no later than {days} days after it is created" : "Lidhja publike do të skadojë jo më vonë se {days} ditë pas krijimit",
    "Link" : "Lidhje",
    "Password protect" : "Mbroje me fjalëkalim",
    "Password" : "Fjalëkalim",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Allow editing" : "Lejo përpunim",
    "Email link to person" : "Dërgo personi lidhjen me email",
    "Send" : "Dërgoje",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "An error occured. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "Adding user..." : "Po shtohet përdorues…",
    "group" : "grup",
    "remote" : "i largët",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Error while retrieving shares" : "Gabim teksa merreshin ndarjet",
    "Unshare" : "Hiqja ndarjen",
    "notify by email" : "njoftoje me email",
    "can share" : "mund të ndajë",
    "can edit" : "mund të ndryshojë",
    "access control" : "kontroll hyrjesh",
    "create" : "krijoje",
    "change" : "ndërroje",
    "delete" : "fshije",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Error unsetting expiration date" : "Gabim në heqjen e datës së skadimit",
    "Error setting expiration date" : "Gabim në caktimin e datës së skadimit",
    "Sending ..." : "Po dërgohet …",
    "Email sent" : "Email-i u dërgua",
    "Warning" : "Kujdes",
    "This share is password-protected" : "Kjo pjesë është e mbrojtur me fjalëkalim",
    "The password is wrong. Try again." : "Fjalëkalimi është i gabuar. Riprovoni.",
    "Sort by date" : "Renditi sipas datash",
    "Sort by name" : "Renditi sipas emrash",
    "Cancel upload" : "Anuloje ngarkimin",
    "Album information" : "Të dhëna albumi",
    "File list" : "Listë kartelash",
    "Sorry, this file could not be found." : "Na ndjeni, kjo kartelë s’u gjet dot.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the wrong file ID was provided" : "u dha ID e gabuar kartele",
    "the file was removed" : "kartela është hequr",
    "the file is corrupt" : "kartela është e dëmtuar",
    "the encryption key is missing" : "mungon kyçi i fshehtëzimeve",
    "Here is the error message returned by the server: " : "Ky është mesazhi i gabimit i kthyer nga shërbyesi: ",
    "Sorry, but the server could not fulfill your request." : "Na ndjeni, por shërbyesi s’e përmbushi dot kërkesën tuaj.",
    "Possible reasons for the problem:" : "Arsye të mundshme për problemin:",
    "a conflicting app was installed" : "qe instaluar një aplikacion konfliktues",
    "a required component is missing or was disconnected" : "mungon ose është shkëputur një përbërës i domosdoshëm",
    "the filesystem is not readable" : "sistemi i kartelave nuk lejon lexim",
    "For more information, please contact your friendly ownCloud administrator." : "Për më tepër të dhëna, ju lutemi, lidhuni me ne përgjegjësin miqësor të ownCloud-it tuaj.",
    "Sorry, this link doesn't seem to work anymore." : "Na ndjeni, kjo lidhje nuk duket se funksionon më.",
    "the item was removed" : "objekti u hoq",
    "the link has expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more information, please ask the person who has sent you this link." : "Për më tepër të dhëna, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "Picture view" : "Pamje Foto"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sq.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeri",
    "There was a problem reading files from this album" : "Pati një problem me leximin e skedarëve prej këtij albumi",
    "Aborting preview. Could not find the file" : "Po ndërpritet paraparja. S’u gjet dot skedari",
    "Could not move \"{file}\", target exists" : "S’u lëviz dot \"{file}\", objektivi ekziston",
    "Could not move \"{file}\"" : "S’u lëviz dot \"{file}\"",
    "No compatible server found at {remote}" : "Nuk u gjet asnjë server i pajtueshëm në {remote}",
    "Invalid server url" : "url e serverit e pavlefshme",
    "Gallery view" : "Pamje Galeri",
    "Could not load the description" : "S’ngarkoi dot përshkrimin",
    "Could not load the description: " : "S’ngarkoi dot përshkrimin: ",
    "Copyright" : "Të drejta kopjimi",
    "Could not load the copyright notice: " : "S’u ngarkua dot shënimi mbi të drejta kopjimi: ",
    "Copyright notice" : "Shënim të drejtash kopjimi",
    "Link to copyright document" : "Lidhje për te dokumenti i të drejtave të kopjimit",
    "This application may not work properly on your browser." : "Ky aplikacion mund të mos punojë si duhet në shfletuesin tuaj.",
    "For an improved experience, please install one of the following alternatives" : "Për një punim më të mirë, ju lutemi, instaloni një nga alternativat vijuese",
    "Your browser is not supported!" : "Shfletuesi juaj nuk mbulohet!",
    "please install one of the following alternatives" : "ju lutemi, instaloni një nga alternativat vijuese",
    "Album cannot be shown" : "Albumi s’shfaqet dot",
    "No media files found" : "S’u gjetën skedar media",
    "Upload pictures in the files app to display them here" : "Ngarkoni foto te aplikacioni i skedarëve që t’i shfaqni këtu",
    "Upload new files via drag and drop or by using the [+] button above" : "Ngarkoni kartela të reja përmes teknikës merr dhe vër, ose duke përdorur butonin [+] me sipër",
    "Configuration error" : "Gabim formësimi",
    "New" : "E re",
    "Hide Album" : "Fshihe Albumin",
    "Could not hide album" : "Albumi s’u fsheh dot",
    "Error loading slideshow template" : "Gabim gjatë ngarkimit të gjedhes për diapozitiva",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Gabim!</strong> S’u prodhua dot një paraparje e kësaj kartele.<br>Ju lutemi, kaloni te diapozitiva pasuese, teksa heqim këtë figurë nga paraqitja",
    "Next" : "Pasuesja",
    "Play" : "Luaje",
    "Pause" : "Pauzë",
    "Previous" : "E mëparshmja",
    "Close" : "Mbylle",
    "Download" : "Shkarko",
    "Toggle background" : "Ndërroni sfondin",
    "Delete" : "Fshije",
    "Could not create file \"{file}\" because it already exists" : "S’u krijua dot kartela \"{file}\" ngaqë ka një të tillë",
    "Could not create file \"{file}\"" : "S’u krijua dot kartela \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" është emër i pavlefshëm kartele.",
    "File name cannot be empty." : "Emri i kartelës s’mund të jetë i zbrazët.",
    "Upload" : "Ngarkoje",
    "Error" : "Gabim",
    "Error while sharing" : "Gabim gjatë ndarjes me të tjerët",
    "Error while unsharing" : "Gabim gjatë heqjes së ndarjes me të tjerët",
    "Error while changing permissions" : "Gabim gjatë ndryshimit të lejeve",
    "Shared with you and the group {group} by {owner}" : "Ndarë me ju dhe me grupin {group} nga {owner}",
    "Shared with you by {owner}" : "Ndarë me ju nga {owner}",
    "Share with users or groups …" : "Ndajeni me përdorues ose grupe …",
    "Share with users, groups or remote users …" : "Ndajeni me përdorues, grupe ose përdorues të largët …",
    "Share" : "Ndajeni me të tjerët",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Ndani me njerëz në servera të tjerë duke përdorut ID-në e Federated Cloud username@example.com/cloud",
    "Share link" : "Ndani lidhjen",
    "The public link will expire no later than {days} days after it is created" : "Lidhja publike do të skadojë jo më vonë se {days} ditë pas krijimit",
    "Link" : "Lidhje",
    "Password protect" : "Mbroje me fjalëkalim",
    "Password" : "Fjalëkalim",
    "Choose a password for the public link" : "Zgjidhni një fjalëkalim për lidhjen publike",
    "Allow editing" : "Lejo përpunim",
    "Email link to person" : "Dërgojani lidhjen me email personit",
    "Send" : "Dërgoje",
    "Set expiration date" : "Caktoni datë skadimi",
    "Expiration" : "Skadim",
    "Expiration date" : "Datë skadimi",
    "No users or groups found for {search}" : "S’u gjetën përdorues ose grupe për {Kërkim}",
    "An error occured. Please try again" : "Ndodhi një gabim. Ju lutemi, riprovoni",
    "Adding user..." : "Po shtohet përdorues…",
    "group" : "grup",
    "remote" : "i largët",
    "Resharing is not allowed" : "Nuk lejohen rindarjet",
    "Error while retrieving shares" : "Gabim teksa merreshin ndarjet",
    "Unshare" : "Hiqja ndarjen",
    "notify by email" : "njoftoje me email",
    "can share" : "mund të ndajë",
    "can edit" : "mund të ndryshojë",
    "access control" : "kontroll hyrjesh",
    "create" : "krijoje",
    "change" : "ndryshoje",
    "delete" : "fshije",
    "Password protected" : "Mbrojtur me fjalëkalim",
    "Error unsetting expiration date" : "Gabim në heqjen e datës së skadimit",
    "Error setting expiration date" : "Gabim në caktimin e datës së skadimit",
    "Sending ..." : "Po dërgohet …",
    "Email sent" : "Email-i u dërgua",
    "Warning" : "Kujdes",
    "This share is password-protected" : "Kjo pjesë është e mbrojtur me fjalëkalim",
    "The password is wrong. Try again." : "Fjalëkalimi është i gabuar. Riprovoni.",
    "Sort by date" : "Renditi sipas datash",
    "Sort by name" : "Renditi sipas emrash",
    "Cancel upload" : "Anuloje ngarkimin",
    "Album information" : "Të dhëna albumi",
    "File list" : "Listë skedarësh",
    "Sorry, this file could not be found." : "Na vjen keq, kjo kartelë s’u gjet dot.",
    "Reasons might be:" : "Arsyet mund të jenë:",
    "the wrong file ID was provided" : "u dha ID e gabuar skedari",
    "the file was removed" : "skedari është hequr",
    "the file is corrupt" : "skedari është i dëmtuar",
    "the encryption key is missing" : "mungon kyçi i fshehtëzimeve",
    "Here is the error message returned by the server: " : "Ky është mesazhi i gabimit i kthyer nga serveri: ",
    "For more information, please contact your friendly Nextcloud administrator." : "Për më shumë informacion, ju lutemi kontaktoni adiministratorit tuaj miqësor të Nextcloud.",
    "Sorry, but the server could not fulfill your request." : "Na vjen keq, por skedari s’e përmbushi dot kërkesën tuaj.",
    "Possible reasons for the problem:" : "Arsye të mundshme për problemin:",
    "a conflicting app was installed" : "qe instaluar një aplikacion konfliktues",
    "a required component is missing or was disconnected" : "mungon ose është shkëputur një përbërës i domosdoshëm",
    "the filesystem is not readable" : "sistemi i skedarëve nuk është i lexueshëm",
    "For more information, please contact your friendly ownCloud administrator." : "Për më tepër të dhëna, ju lutemi, lidhuni me ne përgjegjësin miqësor të ownCloud-it tuaj.",
    "Sorry, this link doesn't seem to work anymore." : "Na vjen keq, kjo lidhje nuk duket se funksionon më.",
    "the item was removed" : "objekti u hoq",
    "the link has expired" : "lidhja ka skaduar",
    "sharing is disabled" : "ndarjet janë çaktivizuar",
    "For more information, please ask the person who has sent you this link." : "Për më tepër informacion, ju lutemi, pyetni personin që ju dërgoi këtë lidhje.",
    "Add to your Nextcloud" : "Shtoni Nextcloudin tuaj",
    "Picture view" : "Pamje Foto"
},
"nplurals=2; plural=(n != 1);");
